#include 	"p16f690.inc"
	GLOBAL PWM_Config
PWM_SECTION1 CODE
PWM_Config
;  
;The following steps should be taken when configuring the ECCP+ module for PWM operation:
;
	;1. Configure the PWM pins P1A and P1B (and P1C and P1D, if used) as inputs by setting the corresponding TRISC bits.
	BANKSEL TRISC
	BSF TRISC, 5	;used in single, half and full bridge mode
	;BSF TRISC, 4	;used in half and ful bridge mode
	;BSF TRISC, 3	;used only in full bridge mode
	;BSF TRISC, 2	;used only in full bridge mode
;
	;2. Set the PWM period by loading the PR2 register: 
		;PWM period =[(PR2)+ 1]* 4* (TOSC)^-1 * (TMR2 prescale value)
;
	;TOSC = 4MHz
	;TMR2 prescaler = 16
	BANKSEL	PR2
	MOVLW 0xFF
	MOVWF PR2
;
	;3. Configure the ECCP+ module for the desired PWM mode and configuration by loading the CCP1CON register with the appropriate values:
;
		; Select one of the available output configurations and direction with the P1M<1:0> bits.
;
	BANKSEL CCP1CON
	;P1M<1:0>: PWM Output Configuration bits
	;If CCP1M<3:2> = 00, 01, 10:
	;xx = P1A assigned as Capture/Compare input; P1B, P1C, P1D assigned as port pins
	;If CCP1M<3:2> = 11:
	;00 = Single output; P1A modulated; P1B, P1C, P1D assigned as port pins
	;01 = Full-bridge output forward; P1D modulated; P1A active; P1B, P1C inactive
	;10 = Half-bridge output; P1A, P1B modulated with dead band control; P1C, P1D assigned as port pins
	;11 = Full-bridge output reverse; P1B modulated; P1C active; P1A, P1D inactive
	BCF CCP1CON, P1M1
	BCF CCP1CON, P1M0
;
		; Select the polarities of the PWM output signals with the CCP1M<3:0> bits.
;
	BANKSEL CCP1CON
	;CCP1M<3:0>: ECCP Mode Select bits
	;0000 = Capture/Compare/PWM off (resets ECCP module)
	;0001 = Unused (reserved)
	;0010 = Compare mode, toggle output on match (CCP1IF bit is set)
	;0011 = Unused (reserved)
	;0100 = Capture mode, every falling edge
	;0101 = Capture mode, every rising edge
	;0110 = Capture mode, every 4th rising edge
	;0111 = Capture mode, every 16th rising edge
	;1000 = Compare mode, set output on match (CCP1IF bit is set)
	;1001 = Compare mode, clear output on match (CCP1IF bit is set)
	;1010 = Compare mode, generate software interrupt on match (CCP1IF bit is set, CCP1 pin is unaffected)
	;1011 = Compare mode, trigger special event (CCP1IF bit is set; CCP1 resets TMR1or TMR2, and starts an A/D conversion, if the A/D module is enabled)
	;1100 = PWM mode; P1A, P1C active-high; P1B, P1D active-high
	;1101 = PWM mode; P1A, P1C active-high; P1B, P1D active-low
	;1110 = PWM mode; P1A, P1C active-low; P1B, P1D active-high
	;1111 = PWM mode; P1A, P1C active-low; P1B, P1D active-low
	BSF CCP1CON, CCP1M3
	BSF CCP1CON, CCP1M2
	BCF CCP1CON, CCP1M1
	BCF CCP1CON, CCP1M0
;
	;4. Set the PWM duty cycle by loading the CCPR1L register and CCP1CON<5:4> bits:
		;PWM duty cycle =(CCPR1L:CCP1CON<5:4>) * (TOSC)^-1 * (TMR2 prescale value)
;
	;0% duty cycle
	BANKSEL CCPR1L
	MOVLW .0
	MOVWF CCPR1L 	
;
	BANKSEL CCP1CON
	;DC1B<1:0>: PWM Duty Cycle Least Significant bits
	;Capture mode: Unused.
	;Compare mode: Unused.
	;PWM mode: These bits are the two LSbs of the PWM duty cycle. The eight MSbs are found in CCPR1L.
	BCF CCP1CON, DC1B1
	BCF CCP1CON, DC1B0
;
	;5. For Half-bridge Output mode, set the dead band delay by loading PWM1CON<6:0> with the appropriate value.
	;Delay = 4 * TOSC * (PWM1CON<6:0>)
	;Delay must be less than the duty cycle
;
	BANKSEL PWM1CON
	;PDC<6:0>: PWM Delay Count bits
	;PDCn = Number of FOSC/4 (4*TOSC) cycles between the scheduled time when a PWM signal
	;should transition active, and the actual time it transitions active.
	BCF PWM1CON, PDC6
	BCF PWM1CON, PDC5	
	BCF PWM1CON, PDC4
	BCF PWM1CON, PDC3
	BCF PWM1CON, PDC2
	BCF PWM1CON, PDC1
	BCF PWM1CON, PDC0
;
	;6. If auto-shutdown operation is required, load the ECCPAS register:
		; Select the auto-shutdown sources using the ECCPAS<2:0> bits.
		; Select the shutdown states of the PWM output pins using PSSAC<3:2> and PSSBD<1:0> bits.
		; Set the ECCPASE bit (ECCPAS<7>).
		; Configure the comparators using the CM1CON0 and CM2CON0 registers (Registers 8-1 and 8-2).
		; Configure the comparator inputs as analog inputs.
;
	BANKSEL ECCPAS
;
	;ECCPASE: ECCP Auto-shutdown Event Status bit
	;1 = A shutdown event has occurred; ECCP outputs are in shutdown state
	;0 = ECCP outputs are operating
	BCF ECCPAS, ECCPASE
;
	;ECCPAS<2:0>: ECCP Auto-shutdown Source Select bits
	;000 = Auto-shutdown is disabled
	;001 = Comparator 1 output change
	;010 = Comparator 2 output change
	;011 = Either Comparator 1 or 2 change
	;100 = VIL on INT pin
	;101 = VIL on INT pin or Comparator 1 change
	;110 = VIL on INT pin or Comparator 2 change
	;111 = VIL on INT pin or Comparator 1 or Comparator 2 change
	BCF ECCPAS, ECCPAS2
	BCF ECCPAS, ECCPAS1
	BCF ECCPAS, ECCPAS0
;
	;PSSACn: Pin P1A and P1C Shutdown State Control bits
	;00 = Drive Pins P1A and P1C to 0
	;01 = Drive Pins P1A and P1C to 1
	;1x = Pins P1A and P1C tri-state
	BCF ECCPAS, PSSAC1
	BCF ECCPAS, PSSAC0
;
	;PSSBDn: Pin P1B and P1D Shutdown State Control bits
	;00 = Drive Pins P1B and P1D to 0
	;01 = Drive Pins P1B and P1D to 1
	;1x = Pins P1B and P1D tri-state
	BCF ECCPAS, PSSBD1
	BCF ECCPAS, PSSBD0
;
	;7. If auto-restart operation is required, set the PRSEN bit (PWM1CON<7>).
;
	BANKSEL PWM1CON
	;PRSEN: PWM Restart Enable bit
	;1 = Upon auto-shutdown, the ECCPASE bit clears automatically once the shutdown event goes away; the PWM restarts automatically.
	;0 = Upon auto-shutdown, ECCPASE must be cleared in software to restart the PWM.
	BSF PWM1CON, PRSEN
;

	;8. Enable PWM outputs after a new PWM cycle has started:
		; Enable the CCP1/P1A, P1B, P1C and/or P1D pin outputs by clearing the respective TRISC bits.
;
	BANKSEL TRISC
	BCF TRISC, 5	;used in single, half and full bridge mode
	;BCF TRISC, 4	;used in half and ful bridge mode
	;BCF TRISC, 3	;used only in full bridge mode
	;BCF TRISC, 2	;used only in full bridge mode
;
		; ECCP will wait until TMR2 overflows (TMR2IF bit is set) to start PWM control
		; Clear the ECCPASE bit (ECCPAS<7>).
;
	;9. Configure Interrupts and TMR2:	DO IN MAIN!
		; Enable global interrupts (GIE), peripheral interrupts (PEIE), and TMR2IE in PIE1 register
		; Clear the TMR2 interrupt flag bit by clearing the TMR2IF bit (PIR1<1>).
		; Set the TMR2 prescale value by loading the T2CKPS bits (T2CON<1:0>).
		; Enable Timer2 by setting the TMR2ON bit (T2CON<2>).
;
	RETURN
	END