#include <p16f690.inc>
	GLOBAL SSP_Config
SSP_SECTION0 CODE
SSP_Config
;
	BANKSEL SSPCON
	;bit 7 WCOL: Write Collision Detect bit
	;1 = The SSPBUF register is written while it is still transmitting the previous word
	;(must be cleared in software)
	;0 = No collision
	BCF SSPCON,WCOL

	;bit 6 SSPOV: Receive Overflow Indicator bit
	;In SPI mode:
	;1 = A new byte is received while the SSPBUF register is still holding the previous data. In case
	;of overflow, the data in SSPSR is lost and the SSPBUF is no longer updated. Overflow can
	;only occur in slave mode. The user must read the SSPBUF, even if only transmitting data,
	;to avoid setting overflow. In master mode the overflow bit is not set since each new reception
	;(and transmission) is initiated by writing to the SSPBUF register.
	;0 = No overflow
	;In I2C mode:
	;1 = A byte is received while the SSPBUF register is still holding the previous byte. SSPOV is a
	;dont care in transmit mode. SSPOV must be cleared in software in either mode.
	;0 = No overflow
	BCF SSPCON,SSPOV

	;bit 5 SSPEN: Synchronous Serial Port Enable bit
	;In both modes, when enabled, these pins must be properly configured as input or output.
	;In SPI mode:
	;1 = Enables serial port and configures SCK, SDO, SDI, and SS as the source of the
	;serial port pins
	;0 = Disables serial port and configures these pins as I/O port pins
	;In I2C mode:
	;1; = Enables the serial port and configures the SDA and SCL pins as the source of the
	;serial port pins
	;0 = Disables serial port and configures these pins as I/O port pins
	BSF SSPCON,SSPEN

	;bit 4 CKP: Clock Polarity Select bit
	;In SPI mode:
	;1 = Idle state for clock is a high level
	;0 = Idle state for clock is a low level
	;In I2C mode:
	;SCK release control
	;1 = Enable clock
	;0 = Holds clock low (clock stretch) (Used to ensure data setup time)
	BSF SSPCON,CKP

	;bit 3:0 SSPM3:SSPM0: Synchronous Serial Port Mode Select bits
	;0000 = SPI master mode, clock = FOSC/4
	;0001 = SPI master mode, clock = FOSC/16
	;0010 = SPI master mode, clock = FOSC/64
	;0011 = SPI master mode, clock = TMR2 output/2
	;0100 = SPI slave mode, clock = SCK pin. SS pin control enabled.
	;0101 = SPI slave mode, clock = SCK pin. SS pin control disabled. SS can be used as I/O pin
	;0110 = I2C slave mode, 7-bit address
	;0111 = I2C slave mode, 10-bit address
	;1000 = Reserved
	;1001 = Reserved
	;1010 = Reserved
	;1011 = I2C firmware controlled master mode (slave idle)
	;1100 = Reserved
	;1101 = Reserved
	;1110 = I2C slave mode, 7-bit address with start and stop bit interrupts enabled
	;1111 = I2C slave mode, 10-bit address with start and stop bit interrupts enabled
	BCF SSPCON,SSPM3
	BSF SSPCON,SSPM2
	BCF SSPCON,SSPM1
	BCF SSPCON,SSPM0
;
        BANKSEL SSPSTAT
        ;bit 7 SMP: SPI Data Input Sample Phase bit
                ;SPI Master mode:
                ;1 = Input data sampled at end of data output time
                ;0 = Input data sampled at middle of data output time (Microwire)
                ;SPI Slave mode:
                ;SMP must be cleared when SPI is used in Slave mode
                ;I2 C mode:
                ;This bit must be maintained clear
        BCF SSPSTAT,SMP               
;
        ;bit 6 CKE: SPI Clock Edge Select bit
                ;SPI mode, CKP = 0:
                ;1 = Data transmitted on rising edge of SCK (Microwire alternate)
                ;0 = Data transmitted on falling edge of SCK
                ;SPI mode, CKP = 1:
                ;1 = Data transmitted on falling edge of SCK (Microwire default)
                ;0 = Data transmitted on rising edge of SCK
                ;I2 C mode:
                ;This bit must be maintained clear
        BSF SSPSTAT,CKE
;
        BANKSEL PIR1
        BCF PIR1, SSPIF			;b3 SSPIE Synchronous Serial Port Interrupt Flag Bit
		BANKSEL SSPBUF
        MOVF SSPBUF,W
        MOVLW 0
        MOVWF SSPBUF			;write 0 to SSPBUF


	RETURN
        END
